@@ -52,11 +52,14 @@ public:
     Tp::AccountPtr account() const;
 
     /** Returns a pointer to the Chatwidget's search bar */
-    ChatSearchBar *chatSearchBar() const;
+    ChatSearchBar* chatSearchBar() const;
 
     /** Returns the icon of this chat window */
     KIcon icon() const;
 
+    /** Returns the icon for the account used in this chat window */
+    KIcon accountIcon() const;
+
     /** returns whether the chat is considered a group chat */
     bool isGroupChat() const;
 
@@ -79,13 +82,15 @@ public:
 
     int unreadMessageCount() const;
 
-    /** Returns true if the user is currently typing or not */
-    bool isUserTyping() const;
-
     QString spellDictionary() const;
 
     void setSpellDictionary(const QString &dict);
 
+    /** Returns the chat state of remote contact */
+    Tp::ChannelChatState remoteChatState();
+
+    bool previousConversationAvailable();
+
 public Q_SLOTS:
     /** toggle the search bar visibility */
     void toggleSearchBar() const;
@@ -116,6 +121,8 @@ protected Q_SLOTS:
 
     void onChatStatusChanged(const Tp::ContactPtr &contact, Tp::ChannelChatState state);
 
+    void onContactBlockStatusChanged(const Tp::ContactPtr &contact, bool blocked);
+
     void onContactPresenceChange(const Tp::ContactPtr &contact, const KTp::Presence &presence);
 
     void onContactAliasChanged(const Tp::ContactPtr &contact, const QString &alias);
@@ -140,7 +147,10 @@ Q_SIGNALS:
     void searchTextComplete(bool found);
 
     /** Emitted when another contact in the channel starts/stops typing (if supported by the protocol)*/
-    void userTypingChanged(bool);
+    void userTypingChanged(Tp::ChannelChatState);
+
+    /** Emitted when a contact is blocked or unblocked */
+    void contactBlockStatusChanged(bool blocked);
 
     void contactPresenceChanged(KTp::Presence presence);
 
@@ -156,6 +166,7 @@ private Q_SLOTS:
     void findPreviousTextInChat(const QString &text, QWebPage::FindFlags flags);
     void onFormatColorReleased();
     void onHistoryFetched(const QList<AdiumThemeContentInfo> &messages);
+    void onChatPausedTimerExpired();
 
 private:
     /** connects necessary signals for the channel */
@@ -165,6 +176,7 @@ private:
     void setupContactModelSignals();
 
     virtual bool isOnTop() const;
+    bool m_previousConversationAvailable;
 
     ChatWidgetPrivate * const d;
 };
